@@ -2,10 +2,10 @@ package Alt::Alien::FFI::System;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.010;
 
 # ABSTRACT: Simplified alternative to Alien::FFI that uses system libffi
-our $VERSION = '0.15_01'; # TRIAL VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 1;
@@ -22,7 +22,7 @@ Alt::Alien::FFI::System - Simplified alternative to Alien::FFI that uses system
 
 =head1 VERSION
 
-version 0.15_01
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -32,10 +32,8 @@ version 0.15_01
 
 This distribution provides an alternative implementation of
 L<Alien::FFI> that is geared toward system integrators when
-libffi is provided by the operating system.  It has no non-core
-requirements for runtume as of Perl 5.8.  It now uses
-use L<Test::Alien> for consistency with the original
-L<Alien::FFI>.
+libffi is provided by the operating system.  It requires 
+Perl 5.10 or better, but has no non-core requirements.
 
 It will NOT attempt to download or install libffi.  If you
 need that, then install the original L<Alien::FFI> instead.
